summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorlauralu <lauralu@google.com>2018-10-18 23:55:24 -0700
committerandroid-build-merger <android-build-merger@google.com>2018-10-18 23:55:24 -0700
commit7b4f263a6ffde3c0600b47a7eccf983d3a7233f2 (patch)
treea4338b1cdadd81246fa903b166ac4c9af2ce304e
parent9cb11c5751d857f0d10d007c7439e861e8d4eeba (diff)
parent9de4e2e95fa6e2abac26d8332a1c41d07f435b2f (diff)
downloadplatform_testing-pie-temp.tar.gz
add interface swipeEmail(Direction direction) and setEmailBody(String body, boolean useKeyboard) Bug: 116809422 Test: in follow-up CL containing CUJs. Change-Id: Ia62a40466f6c8758fe513ffba31b83ffc0aaaaa2pie-temp
am: 9de4e2e95f Change-Id: I48b0216524ed05e38dd3d6ecef847061dd4039a2
-rw-r--r--libraries/app-helpers/interfaces/handheld/src/android/platform/helpers/IGmailHelper.java29
1 files changed, 27 insertions, 2 deletions
diff --git a/libraries/app-helpers/interfaces/handheld/src/android/platform/helpers/IGmailHelper.java b/libraries/app-helpers/interfaces/handheld/src/android/platform/helpers/IGmailHelper.java
index 0a2a2fb92..4c01fa8c8 100644
--- a/libraries/app-helpers/interfaces/handheld/src/android/platform/helpers/IGmailHelper.java
+++ b/libraries/app-helpers/interfaces/handheld/src/android/platform/helpers/IGmailHelper.java
@@ -97,14 +97,28 @@ public interface IGmailHelper extends IAppHelper {
/**
* Setup expectations: Gmail is open and composing an e-mail.
*
* This method will set the e-mail's Body and block until complete. Focus will remain on the
* e-mail body after completion.
*/
public void setEmailBody(String body);
/**
* Setup expectations: Gmail is open and composing an e-mail.
*
+ * This method inputs the e-mail body.
+ *
+ * @param body The messages to input in the e-mail body.
+ * @param useKeyboard Types out the e-mail body by keyboard or not.
+ */
+ default public void setEmailBody(String body, boolean useKeyboard) {
+ throw new UnsupportedOperationException("Not yet implemented.");
+ }
+
+ /**
+ * Setup expectations: Gmail is open and composing an e-mail.
+ *
* This method will press send and block until the device is idle on the original e-mail.
*/
public void clickSendButton();
@@ -207,4 +221,15 @@ public interface IGmailHelper extends IAppHelper {
* @param target the target of the link to click
*/
public void openEmailLink(String target);
+
+ /**
+ * Setup expectations: Gmail is open and an email is open.
+ *
+ * This method swipes the current email.
+ *
+ * @param direction The direction to swipe, only accepts LEFT and RIGHT.
+ */
+ default public void swipeEmail(Direction direction) {
+ throw new UnsupportedOperationException("Not yet implemented.");
+ }
}
@@ -97,14 +97,28 @@ public interface IGmailHelper extends IAppHelper {
* Setup expectations: Gmail is open and composing an e-mail.
*
- * This method will set the e-mail's Body and block until complete. Focus will remain on the
- * e-mail body after completion.
+ * This method will set the e-mail's Body (doesn't use keyboard) and block until complete. Focus
+ * will remain on the e-mail body after completion.
+ *
+ * * @param body The messages to input in the e-mail body.
*/
public void setEmailBody(String body);